package mv3302;

import java.awt.geom.Point2D;
import static mv3302.SimplestMover.NaP;
import simkit.SimEntity;
import simkit.SimEntityBase;
import simkit.random.RandomVariate;

/**
 * A MoverManager that generates a random destination and directs a Mover there.
 * When the Mover reaches that destination, generate the next, etc.
 *
 * @author ahbuss
 */
public class SimpleRandomMoverManager extends SimEntityBase {

    /**
     * Generates the coordinates
     */
    private RandomVariate[] coordinateGenerator;

    /**
     * If true, start on the Run event
     */
    private boolean startOnRun;

    /**
     * Next destination
     */
    protected Point2D nextWayPoint;

    /**
     * set nextWayPoint to clone of NaP
     */
    public SimpleRandomMoverManager() {
        this.nextWayPoint = (Point2D) NaP.clone();
    }

    /**
     *
     * @param coordinateGenerator Given coordinate generators
     * @param startOnRun if true, start in Run event
     */
    public SimpleRandomMoverManager(RandomVariate[] coordinateGenerator, boolean startOnRun) {
        this();
        this.setCoordinateGenerator(coordinateGenerator);
        this.setStartOnRun(startOnRun);
    }

    /**
     * set nextWayPoint to NaP coordinates
     */
    @Override
    public void reset() {
        super.reset();
        nextWayPoint.setLocation(NaP);
    }

    /**
     * If startOnRun, schedule Start event
     */
    public void doRun() {
        firePropertyChange("nextWayPoint", getNextWayPoint());
        if (isStartOnRun()) {
            waitDelay("Start", 0.0);
        }
    }

    /**
     * Generate nextWaypoint<br>
     * schedule MoveTo
     */
    public void doStart() {
        nextWayPoint = new Point2D.Double(coordinateGenerator[0].generate(), coordinateGenerator[1].generate());
        firePropertyChange("nextWaypoint", getNextWayPoint());

        waitDelay("MoveTo", 0.0, nextWayPoint);
    }

    /**
     * To be "heard" from Mover. generate nextWayPoint and schedule MoveTo
     *
     * @param mover Given Mover
     */
    public void doEndMove(SimEntity mover) {
        nextWayPoint = new Point2D.Double(coordinateGenerator[0].generate(), coordinateGenerator[1].generate());
        firePropertyChange("nextWaypoint", getNextWayPoint());

        waitDelay("MoveTo", 0.0, nextWayPoint);
    }

    /**
     * Schedule OrderStop (which should "Stop" the Mover listening)
     */
    public void doStop() {
        waitDelay("OrderStop", 0.0);
    }

    /**
     * @return copy of the coordinateGenerator
     */
    public RandomVariate[] getCoordinateGenerator() {
        return coordinateGenerator.clone();
    }

    /**
     * @param coordinateGenerator the coordinateGenerator to set (copy of)
     */
    public void setCoordinateGenerator(RandomVariate[] coordinateGenerator) {
        this.coordinateGenerator = coordinateGenerator.clone();
    }

    /**
     * @return the startOnRun
     */
    public boolean isStartOnRun() {
        return startOnRun;
    }

    /**
     * @param startOnRun the startOnRun to set
     */
    public void setStartOnRun(boolean startOnRun) {
        this.startOnRun = startOnRun;
    }

    /**
     * @return the nextWayPoint
     */
    public Point2D getNextWayPoint() {
        return nextWayPoint;
    }

}
