package mv3302.sensor;

import simkit.smd.Mover;

/**
 * A simple constant time sensor that detects objects in a given time frame. It
 * extends the AbstractSimpleSensor class.
 */
public final class SimpleConstantTimeSensor extends AbstractSimpleSensor {

    protected double timeToDetect;

    /**
     * Creates a new instance of SimpleConstantTimeSensor with default values.
     */
    public SimpleConstantTimeSensor() {
        super();
    }

    /**
     * Creates a new instance of SimpleConstantTimeSensor with the specified
     * parameters.
     *
     * @param mover the mover object associated with the sensor
     * @param maxRange the maximum range of the sensor
     * @param timeToDetect the time taken by the sensor to detect an object
     */
    public SimpleConstantTimeSensor(Mover mover, double maxRange, double timeToDetect) {
        super(mover, maxRange);
        setTimeToDetect(timeToDetect);
    }

    /**
     *
     * Returns the time taken by the sensor to detect an object.
     *
     * @return the time to detect an object
     */
    public double getTimeToDetect() {
        return timeToDetect;
    }

    /**
     *
     * Sets the time taken by the sensor to detect an object.
     *
     * @param timeToDetect the time to detect an object (must be >= 0.0)
     * @throws IllegalArgumentException if the provided timeToDetect is less
     * than 0.0
     */
    public void setTimeToDetect(double timeToDetect) {
        if (timeToDetect < 0.0) {
            throw new IllegalArgumentException("timeToDetect must be >= 0.0: " + timeToDetect);
        }
        this.timeToDetect = timeToDetect;
    }
}
